summaryrefslogtreecommitdiff
path: root/src/gui/window.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/window.h')
-rw-r--r--src/gui/window.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/gui/window.h b/src/gui/window.h
index be9c9ea1..1bdac52c 100644
--- a/src/gui/window.h
+++ b/src/gui/window.h
@@ -110,7 +110,7 @@ class Window : public gcn::Window, public ConfigListener
/**
* Returns whether the window can be resized.
*/
- bool getResizable();
+ bool isResizable();
/**
* Sets the minimum width of the window.
@@ -146,12 +146,13 @@ class Window : public gcn::Window, public ConfigListener
void scheduleDelete();
/**
* Window dragging and resizing. These methods also makes sure the
* window is not dragged/resized outside of the screen.
*/
void mousePress(int x, int y, int button);
void mouseMotion(int mx, int my);
void mouseRelease(int x, int y, int button);
+ void mouseOut();
/**
* Called when an config option changes.
@@ -146,12 +146,13 @@ class Window : public gcn::Window, public ConfigListener
void scheduleDelete();
/**
- * Window dragging and resizing. These methods also makes sure the
+ * Window dragging and resizing mouse related. These methods also makes sure the
* window is not dragged/resized outside of the screen.
*/